summaryrefslogtreecommitdiff
path: root/networkconfig.h
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>1998-10-13 13:55:51 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>1998-10-13 13:55:51 +0000
commitf84493dde64ebe17dec9be410fe4e288626482e1 (patch)
tree7879ea21d5595ba5696da247e742bf9213acfee6 /networkconfig.h
parent14cbc5066800b010fb3575982247f2005ebc5e73 (diff)
Changed to clarify how to set the network address.
Diffstat (limited to 'networkconfig.h')
-rw-r--r--networkconfig.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/networkconfig.h b/networkconfig.h
index 61425ae..cba278c 100644
--- a/networkconfig.h
+++ b/networkconfig.h
@@ -17,6 +17,16 @@
#include <bsp.h>
/*
+ * Define RTEMS_SET_ETHERNET_ADDRESS if you want to specify the
+ * Ethernet address here. If RTEMS_SET_ETHERNET_ADDRESS is not
+ * defined the driver will choose an address.
+ */
+/* #define RTEMS_SET_ETHERNET_ADDRESS */
+#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
+static char ethernet_address[6] = { 0x08, 0x00, 0x3e, 0x12, 0x28, 0xb1 };
+#endif
+
+/*
* Default network interface
*/
static struct rtems_bsdnet_ifconfig netdriver_config = {
@@ -33,7 +43,11 @@ static struct rtems_bsdnet_ifconfig netdriver_config = {
"255.255.255.0", /* IP net mask */
#endif /* !RTEMS_USE_BOOTP */
- NULL, /* Driver supplies hardware address */
+#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
+ ethernet_address, /* Ethernet hardware address */
+#else
+ NULL, /* Driver supplies hardware address */
+#endif
0 /* Use default driver parameters */
};